import { UserAgent } from "@repobit/dex-utils";
import { getCurrentDate, getCurrentTime } from '../utils.js';
export class PageLoadStartedEvent {
    event = 'page load started';
    pageInstanceID;
    page;
    constructor(page, pageInfo, pageAttributes = {}) {
        this.pageInstanceID = page.environment;
        const [section = '', subSection = '', subSubSection = '', subSubSubSection = ''] = pageInfo.name.split(':');
        const topLevelDomain = window.location.hostname.split('.').splice(1, 2)
            .join('.');
        this.page = {
            info: {
                ...pageInfo,
                section,
                subSection,
                subSubSection,
                subSubSubSection,
                destinationURL: window.location.href,
                queryString: window.location.search,
                referringURL: page.getParamValue('ref') || page.getParamValue('adobe_mc_ref') || document.referrer,
                serverName: window.location.hostname,
                sysEnv: UserAgent.os || '',
                language: page.locale
            },
            attributes: {
                internalPromotionID: page.getParamValue('icid') || '',
                trackingID: page.getParamValue('cid') || '',
                time: getCurrentTime(),
                date: getCurrentDate(),
                domain: topLevelDomain,
                domainPeriod: window.location.hostname.split('.').length - 1,
                ppvScrollData: sessionStorage.getItem('ppvScrollData') || '',
                ppvName: sessionStorage.getItem('ppvName') || '',
                ...pageAttributes
            }
        };
    }
}
//# sourceMappingURL=index.js.map